summaryrefslogtreecommitdiffstats
path: root/kregexpeditor
diff options
context:
space:
mode:
Diffstat (limited to 'kregexpeditor')
-rw-r--r--kregexpeditor/KMultiFormListBox/indexWindow.cpp2
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp6
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h2
-rw-r--r--kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp66
-rw-r--r--kregexpeditor/altnwidget.cpp8
-rw-r--r--kregexpeditor/altnwidget.h2
-rw-r--r--kregexpeditor/auxbuttons.cpp14
-rw-r--r--kregexpeditor/characterswidget.cpp10
-rw-r--r--kregexpeditor/characterswidget.h2
-rw-r--r--kregexpeditor/charselector.cpp14
-rw-r--r--kregexpeditor/compoundwidget.cpp14
-rw-r--r--kregexpeditor/compoundwidget.h2
-rw-r--r--kregexpeditor/concwidget.cpp14
-rw-r--r--kregexpeditor/concwidget.h2
-rw-r--r--kregexpeditor/drag.cpp4
-rw-r--r--kregexpeditor/drag.h2
-rw-r--r--kregexpeditor/dragaccepter.cpp6
-rw-r--r--kregexpeditor/dragaccepter.h2
-rw-r--r--kregexpeditor/editorwindow.cpp8
-rw-r--r--kregexpeditor/editorwindow.h2
-rw-r--r--kregexpeditor/emacsregexpconverter.cpp42
-rw-r--r--kregexpeditor/errormap.cpp6
-rw-r--r--kregexpeditor/gen_qregexpparser.cc4
-rw-r--r--kregexpeditor/infopage.cpp6
-rw-r--r--kregexpeditor/kregexpeditorgui.cpp8
-rw-r--r--kregexpeditor/kregexpeditorprivate.cpp6
-rw-r--r--kregexpeditor/limitedcharlineedit.cpp2
-rw-r--r--kregexpeditor/lookaheadwidget.cpp8
-rw-r--r--kregexpeditor/lookaheadwidget.h2
-rw-r--r--kregexpeditor/main.cpp2
-rw-r--r--kregexpeditor/multicontainerwidget.cpp2
-rw-r--r--kregexpeditor/myfontmetrics.cpp2
-rw-r--r--kregexpeditor/qregexpparser.y4
-rw-r--r--kregexpeditor/qtregexpconverter.cpp58
-rw-r--r--kregexpeditor/regexp.cpp2
-rw-r--r--kregexpeditor/regexpbuttons.cpp8
-rw-r--r--kregexpeditor/regexpconverter.cpp2
-rw-r--r--kregexpeditor/regexpwidget.cpp6
-rw-r--r--kregexpeditor/regexpwidget.h2
-rw-r--r--kregexpeditor/repeatregexp.cpp4
-rw-r--r--kregexpeditor/repeatwidget.cpp12
-rw-r--r--kregexpeditor/repeatwidget.h2
-rw-r--r--kregexpeditor/scrollededitorwindow.cpp2
-rw-r--r--kregexpeditor/selectablelineedit.cpp4
-rw-r--r--kregexpeditor/selectablelineedit.h2
-rw-r--r--kregexpeditor/singlecontainerwidget.cpp2
-rw-r--r--kregexpeditor/test-without-dl/main.cpp4
-rw-r--r--kregexpeditor/textregexp.cpp2
-rw-r--r--kregexpeditor/textwidget.cpp4
-rw-r--r--kregexpeditor/textwidget.h2
-rw-r--r--kregexpeditor/userdefinedregexps.cpp6
-rw-r--r--kregexpeditor/util.cpp2
-rw-r--r--kregexpeditor/verifier.cpp2
-rw-r--r--kregexpeditor/verifybuttons.cpp16
-rw-r--r--kregexpeditor/widgetfactory.cpp4
-rw-r--r--kregexpeditor/zerowidgets.cpp4
-rw-r--r--kregexpeditor/zerowidgets.h2
57 files changed, 215 insertions, 215 deletions
diff --git a/kregexpeditor/KMultiFormListBox/indexWindow.cpp b/kregexpeditor/KMultiFormListBox/indexWindow.cpp
index f81ea07..22bc14f 100644
--- a/kregexpeditor/KMultiFormListBox/indexWindow.cpp
+++ b/kregexpeditor/KMultiFormListBox/indexWindow.cpp
@@ -71,7 +71,7 @@ int indexWindow::exec(const TQPoint & /*start*/, int /*width*/)
// 23 Feb. 2003 11:28 -- Jesper K. Pedersen
/*
// calculate the height of all the elements together.
- // I need to do it this way, as tqsizeHint doesn't report the correct size
+ // I need to do it this way, as sizeHint doesn't report the correct size
// and itemHeight doesn't neither.
int elm_h = lb->item(0)->height(lb) * lb->count();
elm_h += 2*lb->frameWidth();
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
index 6e82e85..3dcab67 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
@@ -94,9 +94,9 @@ void KMultiFormListBoxMultiVisible::updateClipperContent()
// calculate the required size.
for (TQWidget *child = elms->first(); child; child=elms->next()) {
- maxWidth = TQMAX(maxWidth, child->tqsizeHint().width());
+ maxWidth = TQMAX(maxWidth, child->sizeHint().width());
if (strcmp(child->name(), "seperator") != 0) {
- totalHeight += child->tqsizeHint().height();
+ totalHeight += child->sizeHint().height();
count++;
}
else {
@@ -116,7 +116,7 @@ void KMultiFormListBoxMultiVisible::updateClipperContent()
for (TQWidget *child2 = elms->first(); child2; child2=elms->next()) {
int h;
if ( strcmp(child2->name(),"seperator") != 0) {
- h = child2->tqsizeHint().height();
+ h = child2->sizeHint().height();
h += extra;
}
else {
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h b/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
index b4bf36c..90d4e35 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
@@ -60,7 +60,7 @@ public:
// This function must return a string representing the KMultiFormListBox. This is
// used when showing the fast-search menu available from the `Idx' button.
- virtual TQString idxString() { return TQString::tqfromLatin1(""); }
+ virtual TQString idxString() { return TQString::fromLatin1(""); }
public slots:
void acceptIndexButton();
diff --git a/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp b/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
index 42d411b..e21d2aa 100644
--- a/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
+++ b/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
@@ -117,61 +117,61 @@ KWidgetStreamer::KWidgetStreamer ()
// TQCheckBox
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("checked") << TQString::tqfromLatin1("tristate");
- _map.insert(TQString::tqfromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("checked") << TQString::fromLatin1("tristate");
+ _map.insert(TQString::fromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), l);
// TQComboBox
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("editable") << TQString::tqfromLatin1("currentItem")
- << TQString::tqfromLatin1("maxCount") << TQString::tqfromLatin1("insertionPolicy")
- << TQString::tqfromLatin1("autoCompletion");
- _map.insert(TQString::tqfromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("editable") << TQString::fromLatin1("currentItem")
+ << TQString::fromLatin1("maxCount") << TQString::fromLatin1("insertionPolicy")
+ << TQString::fromLatin1("autoCompletion");
+ _map.insert(TQString::fromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), l);
// TQDial
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("tracking") << TQString::tqfromLatin1("wrapping")
- << TQString::tqfromLatin1("value");
- _map.insert(TQString::tqfromLatin1(TQDIAL_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("tracking") << TQString::fromLatin1("wrapping")
+ << TQString::fromLatin1("value");
+ _map.insert(TQString::fromLatin1(TQDIAL_OBJECT_NAME_STRING), l);
// TQLCDNumber
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("numDigits") << TQString::tqfromLatin1("mode")
- << TQString::tqfromLatin1("segmentStyle") << TQString::tqfromLatin1("value");
- _map.insert(TQString::tqfromLatin1(TQLCDNUMBER_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("numDigits") << TQString::fromLatin1("mode")
+ << TQString::fromLatin1("segmentStyle") << TQString::fromLatin1("value");
+ _map.insert(TQString::fromLatin1(TQLCDNUMBER_OBJECT_NAME_STRING), l);
// TQLineEdit
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("text") << TQString::tqfromLatin1("maxLength")
- << TQString::tqfromLatin1("echoMode") << TQString::tqfromLatin1("tqalignment");
- _map.insert(TQString::tqfromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("text") << TQString::fromLatin1("maxLength")
+ << TQString::fromLatin1("echoMode") << TQString::fromLatin1("tqalignment");
+ _map.insert(TQString::fromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), l);
// TQMultiLineEdit
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("text")
- << TQString::tqfromLatin1("tqalignment");
- _map.insert(TQString::tqfromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("text")
+ << TQString::fromLatin1("tqalignment");
+ _map.insert(TQString::fromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), l);
// TQRadioButton
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("checked");
- _map.insert(TQString::tqfromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("checked");
+ _map.insert(TQString::fromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), l);
// TQSlider
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("value");
- _map.insert(TQString::tqfromLatin1(TQSLIDER_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("value");
+ _map.insert(TQString::fromLatin1(TQSLIDER_OBJECT_NAME_STRING), l);
// TQSpinBox
l.clear();
- l << TQString::tqfromLatin1("enabled")
- << TQString::tqfromLatin1("value");
- _map.insert(TQString::tqfromLatin1(TQSPINBOX_OBJECT_NAME_STRING), l);
+ l << TQString::fromLatin1("enabled")
+ << TQString::fromLatin1("value");
+ _map.insert(TQString::fromLatin1(TQSPINBOX_OBJECT_NAME_STRING), l);
}
diff --git a/kregexpeditor/altnwidget.cpp b/kregexpeditor/altnwidget.cpp
index 25befe5..a616310 100644
--- a/kregexpeditor/altnwidget.cpp
+++ b/kregexpeditor/altnwidget.cpp
@@ -81,7 +81,7 @@ void AltnWidget::addNewConcChild(DragAccepter *accepter, ConcWidget *child)
}
-TQSize AltnWidget::tqsizeHint() const
+TQSize AltnWidget::sizeHint() const
{
TQPtrListIterator<RegExpWidget> it(_tqchildren);
// Skip the first child, as we only need half of the size of the first and the
@@ -93,7 +93,7 @@ TQSize AltnWidget::tqsizeHint() const
_tqchildrenHeight = 0;
for ( ; *it ; ++it) {
- TQSize thisChildSize = (*it)->tqsizeHint();
+ TQSize thisChildSize = (*it)->sizeHint();
_tqchildrenWidth = TQMAX(_tqchildrenWidth, thisChildSize.width());
_tqchildrenHeight += thisChildSize.height();
}
@@ -118,7 +118,7 @@ void AltnWidget::paintEvent( TQPaintEvent *e)
dynamic_cast<DragAccepter*>(_tqchildren.at(_tqchildren.count()-1)) ) );
int offset = 0;
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize );
@@ -144,7 +144,7 @@ void AltnWidget::paintEvent( TQPaintEvent *e)
RegExpWidget* child = _tqchildren.at(i);
- TQSize childSize = child->tqsizeHint();
+ TQSize childSize = child->sizeHint();
TQSize curChildSize = child->size();
//-------------------------------------- place the child
diff --git a/kregexpeditor/altnwidget.h b/kregexpeditor/altnwidget.h
index 519eba5..8404712 100644
--- a/kregexpeditor/altnwidget.h
+++ b/kregexpeditor/altnwidget.h
@@ -34,7 +34,7 @@ public:
AltnWidget( AltnRegExp* regexp, RegExpEditorWindow* editorWindow,
TQWidget* parent, const char* name = 0);
virtual void addNewChild(DragAccepter *accepter, RegExpWidget *child);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual void applyRegExpToSelection( RegExpType type );
virtual RegExpType type() const { return ALTN; }
diff --git a/kregexpeditor/auxbuttons.cpp b/kregexpeditor/auxbuttons.cpp
index 855f6d1..3b7032e 100644
--- a/kregexpeditor/auxbuttons.cpp
+++ b/kregexpeditor/auxbuttons.cpp
@@ -38,44 +38,44 @@ AuxButtons::AuxButtons( TQWidget* parent, const char* name = 0)
TQBoxLayout* tqlayout = boxLayout();
_undo = new TQToolButton( this );
- _undo->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("undo") ) );
+ _undo->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("undo") ) );
tqlayout->addWidget( _undo );
connect( _undo, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(undo()) );
TQToolTip::add( _undo, i18n( "Undo" ) );
_redo = new TQToolButton( this );
- _redo->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("redo") ) );
+ _redo->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("redo") ) );
tqlayout->addWidget( _redo );
connect( _redo, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(redo()) );
TQToolTip::add( _redo, i18n( "Redo" ) );
_cut = new TQToolButton( this );
- _cut->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("editcut") ) );
+ _cut->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("editcut") ) );
tqlayout->addWidget( _cut );
connect( _cut, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(cut()) );
TQToolTip::add( _cut, i18n( "Cut" ) );
_copy = new TQToolButton( this );
- _copy->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("editcopy") ) );
+ _copy->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("editcopy") ) );
tqlayout->addWidget( _copy );
connect( _copy, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(copy()) );
TQToolTip::add( _copy, i18n( "Copy" ) );
_paste = new TQToolButton( this );
- _paste->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("editpaste")) );
+ _paste->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("editpaste")) );
tqlayout->addWidget( _paste );
connect( _paste, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(paste()) );
TQToolTip::add( _paste, i18n( "Paste" ) );
_save = new TQToolButton( this );
- _save->setIconSet( Util::getSystemIconSet(TQString::tqfromLatin1("filesave")) );
+ _save->setIconSet( Util::getSystemIconSet(TQString::fromLatin1("filesave")) );
tqlayout->addWidget( _save );
connect( _save, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(save()) );
TQToolTip::add( _save, i18n( "Save" ) );
TQToolButton* button = new TQToolButton(this);
- button->setPixmap( Util::getSystemIcon( TQString::tqfromLatin1("contexthelp") ) );
+ button->setPixmap( Util::getSystemIcon( TQString::fromLatin1("contexthelp") ) );
tqlayout->addWidget( button );
connect(button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEnterWhatsThis()));
diff --git a/kregexpeditor/characterswidget.cpp b/kregexpeditor/characterswidget.cpp
index 227f605..7f64d56 100644
--- a/kregexpeditor/characterswidget.cpp
+++ b/kregexpeditor/characterswidget.cpp
@@ -60,7 +60,7 @@ CharactersWidget::~CharactersWidget()
}
-TQSize CharactersWidget::tqsizeHint() const
+TQSize CharactersWidget::sizeHint() const
{
TQFontMetrics metrics = fontMetrics();
_textSize = HackCalculateFontSize(metrics, title());
@@ -78,7 +78,7 @@ TQSize CharactersWidget::tqsizeHint() const
void CharactersWidget::paintEvent(TQPaintEvent *e)
{
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize );
@@ -118,7 +118,7 @@ RegExp* CharactersWidget::regExp() const
TQString CharactersWidget::text() const
{
- TQString res = TQString::tqfromLatin1("");
+ TQString res = TQString::fromLatin1("");
if (_regexp->wordChar())
res += i18n("- A word character\n");
@@ -186,8 +186,8 @@ int CharactersWidget::edit()
TQApplication::restoreOverrideCursor();
}
- _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->tqsizeHint().width()/2,
- _configWindow->tqsizeHint().height()/2));
+ _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->sizeHint().width()/2,
+ _configWindow->sizeHint().height()/2));
int ret = _configWindow->exec(_regexp );
if ( ret == TQDialog::Accepted ) {
_editorWindow->updateContent( 0 );
diff --git a/kregexpeditor/characterswidget.h b/kregexpeditor/characterswidget.h
index ccc8852..576e6f1 100644
--- a/kregexpeditor/characterswidget.h
+++ b/kregexpeditor/characterswidget.h
@@ -46,7 +46,7 @@ public:
CharactersWidget( TextRangeRegExp* regexp, RegExpEditorWindow* editorWindow,
TQWidget* parent, const char* name = 0 );
~CharactersWidget();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return CHARSET; }
virtual RegExpWidget* findWidgetToEdit( TQPoint globalPos );
diff --git a/kregexpeditor/charselector.cpp b/kregexpeditor/charselector.cpp
index 5f60475..32e2a79 100644
--- a/kregexpeditor/charselector.cpp
+++ b/kregexpeditor/charselector.cpp
@@ -60,7 +60,7 @@ CharSelector::CharSelector( TQWidget* parent, const char* name )
items << i18n("Normal Character")
<< i18n("Unicode Char in Hex.")
<< i18n("Unicode Char in Oct.")
- << TQString::tqfromLatin1("----")
+ << TQString::fromLatin1("----")
<< i18n("The Bell Character (\\a)")
<< i18n("The Form Feed Character (\\f)")
<< i18n("The Line Feed Character (\\n)")
@@ -169,17 +169,17 @@ TQString CharSelector::text() const
case 3: // The seperator
break;
case 4:
- return TQString::tqfromLatin1("\\a");
+ return TQString::fromLatin1("\\a");
case 5:
- return TQString::tqfromLatin1("\\f");
+ return TQString::fromLatin1("\\f");
case 6:
- return TQString::tqfromLatin1("\\n");
+ return TQString::fromLatin1("\\n");
case 7:
- return TQString::tqfromLatin1("\\r");
+ return TQString::fromLatin1("\\r");
case 8:
- return TQString::tqfromLatin1("\\t");
+ return TQString::fromLatin1("\\t");
case 9:
- return TQString::tqfromLatin1("\\v");
+ return TQString::fromLatin1("\\v");
}
return TQString();
}
diff --git a/kregexpeditor/compoundwidget.cpp b/kregexpeditor/compoundwidget.cpp
index c43dcbb..044ec85 100644
--- a/kregexpeditor/compoundwidget.cpp
+++ b/kregexpeditor/compoundwidget.cpp
@@ -135,10 +135,10 @@ void CompoundWidget::init( )
_backRefId = -1;
}
-TQSize CompoundWidget::tqsizeHint() const
+TQSize CompoundWidget::sizeHint() const
{
TQFontMetrics metrics = fontMetrics();
- _childSize = _child->tqsizeHint();
+ _childSize = _child->sizeHint();
_textSize = metrics.size( 0, _content->title() );
int width, height;
@@ -164,7 +164,7 @@ TQSize CompoundWidget::tqsizeHint() const
void CompoundWidget::paintEvent( TQPaintEvent *e )
{
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize);
@@ -220,8 +220,8 @@ void CompoundWidget::paintEvent( TQPaintEvent *e )
}
else {
TQSize curSize = _child->size();
- TQSize newSize = TQSize( TQMAX( _child->tqsizeHint().width(), mySize.width()-2*pw),
- _child->tqsizeHint().height());
+ TQSize newSize = TQSize( TQMAX( _child->sizeHint().width(), mySize.width()-2*pw),
+ _child->sizeHint().height());
_child->move( pw, childY );
if ( curSize != newSize ) {
@@ -296,8 +296,8 @@ bool CompoundWidget::updateSelection( bool parentSelected )
int CompoundWidget::edit()
{
- _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->tqsizeHint().width()/2,
- _configWindow->tqsizeHint().height()/2) );
+ _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->sizeHint().width()/2,
+ _configWindow->sizeHint().height()/2) );
TQDataStream stream( _backup, IO_WriteOnly );
KWidgetStreamer streamer;
streamer.toStream( TQT_TQOBJECT(_content), stream );
diff --git a/kregexpeditor/compoundwidget.h b/kregexpeditor/compoundwidget.h
index 047f942..ad16de8 100644
--- a/kregexpeditor/compoundwidget.h
+++ b/kregexpeditor/compoundwidget.h
@@ -69,7 +69,7 @@ public:
TQWidget* parent, const char* name = 0);
virtual bool updateSelection( bool parentSelected );
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return COMPOUND; }
virtual int edit();
diff --git a/kregexpeditor/concwidget.cpp b/kregexpeditor/concwidget.cpp
index 16690be..53f7f1d 100644
--- a/kregexpeditor/concwidget.cpp
+++ b/kregexpeditor/concwidget.cpp
@@ -78,14 +78,14 @@ void ConcWidget::init()
}
-TQSize ConcWidget::tqsizeHint() const
+TQSize ConcWidget::sizeHint() const
{
int tqchildrenWidth = 0;
int tqchildrenHeight = 0;
TQPtrListIterator<RegExpWidget> it(_tqchildren);
for ( ; *it; ++it) {
- TQSize thisChildSize = (*it)->tqsizeHint();
+ TQSize thisChildSize = (*it)->sizeHint();
tqchildrenWidth += thisChildSize.width();
tqchildrenHeight = TQMAX(tqchildrenHeight, thisChildSize.height());
}
@@ -106,7 +106,7 @@ void ConcWidget::paintEvent( TQPaintEvent *e)
_tqchildren.at(0)->setGeometry( 0, 0, size().width(), size().height() );
}
else {
- TQSize myReqSize = tqsizeHint();
+ TQSize myReqSize = sizeHint();
TQSize mySize(TQMAX(myReqSize.width(), size().width()),
TQMAX(myReqSize.height(), size().height()));
@@ -131,12 +131,12 @@ void ConcWidget::paintEvent( TQPaintEvent *e)
continue;
RegExpWidget* child = _tqchildren.at(i);
- TQSize childSize = child->tqsizeHint();
+ TQSize childSize = child->sizeHint();
TQSize curChildSize = child->size();
//----------------------------- first place the accepter
int x = offset;
- int w = accepter->tqsizeHint().width();
+ int w = accepter->sizeHint().width();
if ( i == 1 ) w+= extra;
int h = TQMAX( lastHeight, childSize.height() );
int y = (mySize.height() - h)/2;
@@ -180,7 +180,7 @@ void ConcWidget::paintEvent( TQPaintEvent *e)
// dynamic_cast is ASSERTed at top
int x = offset;
int h = lastHeight;
- int w = accepter->tqsizeHint().width() + extra;
+ int w = accepter->sizeHint().width() + extra;
int y = (mySize.height()-h)/2;
accepter->setGeometry( x, y, w, h );
}
@@ -240,7 +240,7 @@ bool ConcWidget::updateSelection(bool parentSelected)
++it; // Skip past the first DragAccepter
for ( ; *it; it +=2 ) {
if ( (*it)->isSelected() ) {
- _maxSelectedHeight = TQMAX( _maxSelectedHeight, (*it)->tqsizeHint().height() );
+ _maxSelectedHeight = TQMAX( _maxSelectedHeight, (*it)->sizeHint().height() );
}
}
diff --git a/kregexpeditor/concwidget.h b/kregexpeditor/concwidget.h
index bff85a7..b5dbf48 100644
--- a/kregexpeditor/concwidget.h
+++ b/kregexpeditor/concwidget.h
@@ -40,7 +40,7 @@ public:
TQWidget* parent, const char* name = 0);
void init();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual bool updateSelection(bool parentSelected);
virtual bool isSelected() const;
diff --git a/kregexpeditor/drag.cpp b/kregexpeditor/drag.cpp
index 9c2b1ca..e17973c 100644
--- a/kregexpeditor/drag.cpp
+++ b/kregexpeditor/drag.cpp
@@ -39,7 +39,7 @@ bool RegExpWidgetDrag::canDecode( TQDragMoveEvent* event )
RegExpWidget* RegExpWidgetDrag::decode(TQDropEvent* event, RegExpEditorWindow* window,
TQWidget* parent)
{
- TQByteArray payload = event->tqencodedData("KRegExpEditor/widgetdrag" );
+ TQByteArray payload = event->encodedData("KRegExpEditor/widgetdrag" );
TQTextStream stream( payload, IO_ReadOnly );
TQString str = stream.read();
RegExp* regexp = WidgetFactory::createRegExp( str );
@@ -58,7 +58,7 @@ const char * RegExpWidgetDrag::format ( int i ) const
return 0;
}
-TQByteArray RegExpWidgetDrag::tqencodedData ( const char* format ) const
+TQByteArray RegExpWidgetDrag::encodedData ( const char* format ) const
{
TQByteArray data;
TQTextStream stream( data, IO_WriteOnly );
diff --git a/kregexpeditor/drag.h b/kregexpeditor/drag.h
index 699d1e8..e32b02e 100644
--- a/kregexpeditor/drag.h
+++ b/kregexpeditor/drag.h
@@ -34,7 +34,7 @@ public:
RegExpWidgetDrag( RegExp* regexp , TQWidget* dragSource);
~RegExpWidgetDrag();
virtual const char * format ( int i = 0 ) const;
- virtual TQByteArray tqencodedData ( const char * ) const;
+ virtual TQByteArray encodedData ( const char * ) const;
static bool canDecode(TQDragMoveEvent* event);
static RegExpWidget* decode(TQDropEvent* event, RegExpEditorWindow* window,
TQWidget* parent);
diff --git a/kregexpeditor/dragaccepter.cpp b/kregexpeditor/dragaccepter.cpp
index 6bd049e..f336dbd 100644
--- a/kregexpeditor/dragaccepter.cpp
+++ b/kregexpeditor/dragaccepter.cpp
@@ -28,7 +28,7 @@ DragAccepter::DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *paren
setAcceptDrops(TRUE);
}
-TQSize DragAccepter::tqsizeHint() const
+TQSize DragAccepter::sizeHint() const
{
return TQSize(10,10);
}
@@ -100,7 +100,7 @@ void DragAccepter::mouseReleaseEvent( TQMouseEvent* event )
void DragAccepter::dragEnterEvent(TQDragEnterEvent *event)
{
- bool selfDrag = ( event->source() && event->source()->tqtopLevelWidget() == tqtopLevelWidget() && _isSelected );
+ bool selfDrag = ( event->source() && event->source()->topLevelWidget() == topLevelWidget() && _isSelected );
event->accept(RegExpWidgetDrag::canDecode( event ) && !selfDrag );
}
@@ -124,7 +124,7 @@ void DragAccepter::dropEvent(TQDropEvent *event)
w->update();
_editorWindow->updateContent( this );
- bool selfDrag = ( event->source() && event->source()->tqtopLevelWidget() == tqtopLevelWidget() );
+ bool selfDrag = ( event->source() && event->source()->topLevelWidget() == topLevelWidget() );
if ( ! selfDrag )
_editorWindow->clearSelection( true );
else {
diff --git a/kregexpeditor/dragaccepter.h b/kregexpeditor/dragaccepter.h
index a3737d9..c9c6fd8 100644
--- a/kregexpeditor/dragaccepter.h
+++ b/kregexpeditor/dragaccepter.h
@@ -32,7 +32,7 @@ class DragAccepter :public RegExpWidget
public:
DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *parent,
const char *name = 0);
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return DRAGACCEPTER; }
void setDrawLine( bool drawLine ) { _drawLine = drawLine; }
diff --git a/kregexpeditor/editorwindow.cpp b/kregexpeditor/editorwindow.cpp
index 8e3cc20..a21cb21 100644
--- a/kregexpeditor/editorwindow.cpp
+++ b/kregexpeditor/editorwindow.cpp
@@ -236,9 +236,9 @@ void RegExpEditorWindow::updateContent( TQWidget* focusChild)
emit contentChanged( p );
}
-TQSize RegExpEditorWindow::tqsizeHint() const
+TQSize RegExpEditorWindow::sizeHint() const
{
- return _top->tqsizeHint();
+ return _top->sizeHint();
}
void RegExpEditorWindow::paintEvent( TQPaintEvent* event )
@@ -298,7 +298,7 @@ void RegExpEditorWindow::cutCopyAux( TQPoint pos )
void RegExpEditorWindow::slotStartPasteAction()
{
- TQByteArray data = tqApp->tqclipboard()->data()->tqencodedData( "KRegExpEditor/widgetdrag" );
+ TQByteArray data = tqApp->tqclipboard()->data()->encodedData( "KRegExpEditor/widgetdrag" );
TQTextStream stream( data, IO_ReadOnly );
TQString str = stream.read();
@@ -431,7 +431,7 @@ void RegExpEditorWindow::updateCursorUnderPoint()
{
RegExpWidget* widget = _top->widgetUnderPoint( TQCursor::pos(), false );
if ( widget )
- widget->updatetqCursorShape();
+ widget->updateCursorShape();
}
void RegExpEditorWindow::emitVerifyRegExp()
diff --git a/kregexpeditor/editorwindow.h b/kregexpeditor/editorwindow.h
index 58377c6..c8899a6 100644
--- a/kregexpeditor/editorwindow.h
+++ b/kregexpeditor/editorwindow.h
@@ -110,7 +110,7 @@ public:
*/
void showRMBMenu( bool enableCutCopy );
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
diff --git a/kregexpeditor/emacsregexpconverter.cpp b/kregexpeditor/emacsregexpconverter.cpp
index 0d0f6d4..5cfa54d 100644
--- a/kregexpeditor/emacsregexpconverter.cpp
+++ b/kregexpeditor/emacsregexpconverter.cpp
@@ -43,7 +43,7 @@ TQString EmacsRegExpConverter::toString( AltnRegExp* regexp, bool markSelection
RegExpList list = regexp->tqchildren();
for ( RegExpListIt it(list); *it; ++it ) {
if ( !first ) {
- res += TQString::tqfromLatin1("\\|");
+ res += TQString::fromLatin1("\\|");
}
first = false;
res += toStr( *it, markSelection );
@@ -61,8 +61,8 @@ TQString EmacsRegExpConverter::toString( ConcRegExp* regexp, bool markSelection
TQString startPar = TQString::fromLocal8Bit("");
TQString endPar = TQString::fromLocal8Bit("");
if ( (*it)->precedence() < regexp->precedence() ) {
- startPar = TQString::tqfromLatin1( "\\(" );
- endPar = TQString::tqfromLatin1( "\\)" );
+ startPar = TQString::fromLatin1( "\\(" );
+ endPar = TQString::fromLatin1( "\\)" );
}
res += startPar + toStr( *it, markSelection ) + endPar;
@@ -112,7 +112,7 @@ TQString EmacsRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSel
// Now insert the ranges.
TQPtrList<StringPair> ranges = regexp->range();
for ( TQPtrListIterator<StringPair> it(ranges); *it; ++it ) {
- txt.append((*it)->first()+ TQString::tqfromLatin1("-")+ (*it)->second());
+ txt.append((*it)->first()+ TQString::fromLatin1("-")+ (*it)->second());
}
// Ok, its time to build each part of the regexp, here comes the rule:
@@ -122,20 +122,20 @@ TQString EmacsRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSel
// finally if '^' is one of the characters, then it must not be the first
// one!
- TQString res = TQString::tqfromLatin1("[");
+ TQString res = TQString::fromLatin1("[");
if ( regexp->negate() )
- res.append(TQString::tqfromLatin1("^"));
+ res.append(TQString::fromLatin1("^"));
// a ']' must be the first character in teh range.
if ( foundParenthesis ) {
- res.append(TQString::tqfromLatin1("]"));
+ res.append(TQString::fromLatin1("]"));
}
// a '-' must be the first character ( only coming after a ']')
if ( foundDash ) {
- res.append(TQString::tqfromLatin1("-"));
+ res.append(TQString::fromLatin1("-"));
}
res += txt;
@@ -153,7 +153,7 @@ TQString EmacsRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSel
res.append( TQChar( '^' ) );
}
- res.append(TQString::tqfromLatin1("]"));
+ res.append(TQString::fromLatin1("]"));
return res;
}
@@ -165,7 +165,7 @@ TQString EmacsRegExpConverter::toString( CompoundRegExp* regexp, bool markSelect
TQString EmacsRegExpConverter::toString( DotRegExp* /*regexp*/, bool /*markSelection*/ )
{
- return TQString::tqfromLatin1( "." );
+ return TQString::fromLatin1( "." );
}
TQString EmacsRegExpConverter::toString( PositionRegExp* regexp, bool /*markSelection*/ )
@@ -173,18 +173,18 @@ TQString EmacsRegExpConverter::toString( PositionRegExp* regexp, bool /*markSele
static bool haveWarned = false;
switch ( regexp->position()) {
case PositionRegExp::BEGLINE:
- return TQString::tqfromLatin1("^");
+ return TQString::fromLatin1("^");
case PositionRegExp::ENDLINE:
- return TQString::tqfromLatin1("$");
+ return TQString::fromLatin1("$");
case PositionRegExp::WORDBOUNDARY:
case PositionRegExp::NONWORDBOUNDARY:
if ( ! haveWarned ) {
KMessageBox::sorry( 0, i18n( "Word boundary and non word boundary is not supported in Emacs syntax" ) );
haveWarned = true;
- return TQString::tqfromLatin1("");
+ return TQString::fromLatin1("");
}
}
- return TQString::tqfromLatin1("");
+ return TQString::fromLatin1("");
}
TQString EmacsRegExpConverter::toString( RepeatRegExp* regexp, bool markSelection )
@@ -195,8 +195,8 @@ TQString EmacsRegExpConverter::toString( RepeatRegExp* regexp, bool markSelectio
TQString endPar;
if ( child->precedence() < regexp->precedence() ) {
- startPar = TQString::tqfromLatin1( "\\(" );
- endPar = TQString::tqfromLatin1( "\\)" );
+ startPar = TQString::fromLatin1( "\\(" );
+ endPar = TQString::fromLatin1( "\\)" );
}
if (regexp->min() == 0 && regexp->max() == -1) {
@@ -209,17 +209,17 @@ TQString EmacsRegExpConverter::toString( RepeatRegExp* regexp, bool markSelectio
return startPar + cText + endPar + TQString::fromLocal8Bit("+");
}
else {
- TQString res = TQString::tqfromLatin1("");
+ TQString res = TQString::fromLatin1("");
for ( int i = 0; i < regexp->min(); ++i ) {
- res += TQString::tqfromLatin1( "\\(" ) + cText + TQString::tqfromLatin1( "\\)" );
+ res += TQString::fromLatin1( "\\(" ) + cText + TQString::fromLatin1( "\\)" );
}
if ( regexp->max() != -1 ) {
for ( int i = regexp->min(); i < regexp->max(); ++i ) {
- res += TQString::tqfromLatin1("\\(") + cText + TQString::tqfromLatin1("\\)?");
+ res += TQString::fromLatin1("\\(") + cText + TQString::fromLatin1("\\)?");
}
}
else
- res += TQString::tqfromLatin1("+");
+ res += TQString::fromLatin1("+");
return res;
}
@@ -244,7 +244,7 @@ TQString EmacsRegExpConverter::toString( TextRegExp* regexp, bool /*markSelectio
TQString EmacsRegExpConverter::name()
{
- return TQString::tqfromLatin1( "Emacs" );
+ return TQString::fromLatin1( "Emacs" );
}
int EmacsRegExpConverter::features()
diff --git a/kregexpeditor/errormap.cpp b/kregexpeditor/errormap.cpp
index 41a8c00..65ca557 100644
--- a/kregexpeditor/errormap.cpp
+++ b/kregexpeditor/errormap.cpp
@@ -47,7 +47,7 @@ void ErrorMap::lineStartError()
{
if ( ! _prevLineStartError ) {
KMessageBox::information( 0, i18n("Your regular expression is invalid, due to something preceding a 'line start'."),
- i18n("Regular Expression Error"), TQString::tqfromLatin1("KRegExpEditorLineStartError") );
+ i18n("Regular Expression Error"), TQString::fromLatin1("KRegExpEditorLineStartError") );
}
_lineStartError = true;
}
@@ -56,7 +56,7 @@ void ErrorMap::lineEndError()
{
if ( !_prevLineEndError ) {
KMessageBox::information( 0, i18n("Your regular expression is invalid, due to something following a 'line end'."),
- i18n("Regular Expression Error"), TQString::tqfromLatin1("KRegExpEditorLineEndError") );
+ i18n("Regular Expression Error"), TQString::fromLatin1("KRegExpEditorLineEndError") );
}
_lineEndError = true;
}
@@ -66,7 +66,7 @@ void ErrorMap::lookAheadError()
{
if ( !_prevLookAHeadError ) {
KMessageBox::information( 0, i18n("Your regular expression is invalid. 'Look Ahead' regular expression must be the last sub expression."),
- i18n("Regular Expression Error"), TQString::tqfromLatin1("KRegExpEditorLookAHeadError") );
+ i18n("Regular Expression Error"), TQString::fromLatin1("KRegExpEditorLookAHeadError") );
}
_lookAHeadError = true;
}
diff --git a/kregexpeditor/gen_qregexpparser.cc b/kregexpeditor/gen_qregexpparser.cc
index 8a7b5bf..9a842b6 100644
--- a/kregexpeditor/gen_qregexpparser.cc
+++ b/kregexpeditor/gen_qregexpparser.cc
@@ -1049,7 +1049,7 @@ yyreduce:
yyval.regexp = new AltnRegExp( false );
dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( yyvsp[-1].regexp );
}
- dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( new TextRegExp( false, TQString::tqfromLatin1("") ) );
+ dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( new TextRegExp( false, TQString::fromLatin1("") ) );
}
break;
@@ -1057,7 +1057,7 @@ yyreduce:
#line 107 "qregexpparser.y"
{
yyval.regexp = new AltnRegExp( false );
- dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( new TextRegExp( false, TQString::tqfromLatin1("") ) );
+ dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( new TextRegExp( false, TQString::fromLatin1("") ) );
dynamic_cast<AltnRegExp*>( yyval.regexp )->addRegExp( yyvsp[0].regexp );
}
break;
diff --git a/kregexpeditor/infopage.cpp b/kregexpeditor/infopage.cpp
index 42d473e..bd192e2 100644
--- a/kregexpeditor/infopage.cpp
+++ b/kregexpeditor/infopage.cpp
@@ -28,7 +28,7 @@ InfoPage::InfoPage( TQWidget* parent, const char* name )
:KTextBrowser( parent, name )
{
TQString txt =
- TQString::tqfromLatin1( "<qt>" ) +
+ TQString::fromLatin1( "<qt>" ) +
i18n( "Translators, feel free to add yourself in the text below, asking for a postcard ;-), "
"also feel free to add a section saying <h2>Translators</h2>. "
"Kind regards, and thanks for your work - Jesper.",
@@ -58,14 +58,14 @@ InfoPage::InfoPage( TQWidget* parent, const char* name )
"<h2>Author</h2>"
"<a href=\"http://www.blackie.dk/\">Jesper K. Pedersen</a> &lt;<a href=\"mailto:blackie@kde.org\">blackie@kde.org</a>&gt;")
- + TQString::tqfromLatin1( "</qt>" );
+ + TQString::fromLatin1( "</qt>" );
setText( txt );
}
void InfoPage::setSource ( const TQString& name )
{
#ifdef TQT_ONLY
- mimeSourceFactory()->setFilePath( TQStringList() << TQString::tqfromLatin1("manual/"));
+ mimeSourceFactory()->setFilePath( TQStringList() << TQString::fromLatin1("manual/"));
TQString nm = name;
if ( nm.endsWith("/") )
nm = nm.left( nm.length()-1);
diff --git a/kregexpeditor/kregexpeditorgui.cpp b/kregexpeditor/kregexpeditorgui.cpp
index 95c0f25..1a2e371 100644
--- a/kregexpeditor/kregexpeditorgui.cpp
+++ b/kregexpeditor/kregexpeditorgui.cpp
@@ -117,16 +117,16 @@ void KRegExpEditorGUIDialog::doSomething( TQString method, void* arguments )
void KRegExpEditorGUI::doSomething( TQString method, void* arguments )
{
- if ( method == TQString::tqfromLatin1( "setCaseSensitive" ) ) {
+ if ( method == TQString::fromLatin1( "setCaseSensitive" ) ) {
_editor->setCaseSensitive( (bool) arguments );
}
- else if ( method == TQString::tqfromLatin1("setMinimal") ) {
+ else if ( method == TQString::fromLatin1("setMinimal") ) {
_editor->setMinimal( (bool) arguments );
}
- else if ( method == TQString::tqfromLatin1("setSyntax") ) {
+ else if ( method == TQString::fromLatin1("setSyntax") ) {
_editor->setSyntax( *((TQString*) arguments) );
}
- else if ( method == TQString::tqfromLatin1("setAllowNonTQtSyntax") ) {
+ else if ( method == TQString::fromLatin1("setAllowNonTQtSyntax") ) {
_editor->setAllowNonTQtSyntax( (bool) arguments );
}
else {
diff --git a/kregexpeditor/kregexpeditorprivate.cpp b/kregexpeditor/kregexpeditorprivate.cpp
index 5d9df7a..c74531e 100644
--- a/kregexpeditor/kregexpeditorprivate.cpp
+++ b/kregexpeditor/kregexpeditorprivate.cpp
@@ -158,7 +158,7 @@ KRegExpEditorPrivate::KRegExpEditorPrivate(TQWidget *parent, const char *name)
TQLabel* label = new TQLabel( i18n("ASCII syntax:"), this );
tqlayout->addWidget( label );
clearButton = new TQToolButton( this );
- const TQString icon( TQString::tqfromLatin1( TQApplication::reverseLayout() ? "clear_left" : "locationbar_erase" ) );
+ const TQString icon( TQString::fromLatin1( TQApplication::reverseLayout() ? "clear_left" : "locationbar_erase" ) );
TQIconSet clearIcon = SmallIconSet( icon );
clearButton->setIconSet( clearIcon );
tqlayout->addWidget( clearButton );
@@ -174,7 +174,7 @@ KRegExpEditorPrivate::KRegExpEditorPrivate(TQWidget *parent, const char *name)
#ifdef TQT_ONLY
TQPixmap pix( "icons/error.png" );
#else
- TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::tqfromLatin1("kregexpeditor/pics/error.png") ), KIcon::Toolbar );
+ TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::fromLatin1("kregexpeditor/pics/error.png") ), KIcon::Toolbar );
#endif
_error = new TQLabel( this );
_error->setPixmap( pix );
@@ -196,7 +196,7 @@ KRegExpEditorPrivate::KRegExpEditorPrivate(TQWidget *parent, const char *name)
accel->connectItem( accel->insertItem( CTRL+Key_Z ), this, TQT_SLOT( slotUndo() ) );
accel->connectItem( accel->insertItem( CTRL+Key_R ), this, TQT_SLOT( slotRedo() ) );
- setSyntax( TQString::tqfromLatin1( "TQt" ) );
+ setSyntax( TQString::fromLatin1( "TQt" ) );
}
TQString KRegExpEditorPrivate::regexp()
diff --git a/kregexpeditor/limitedcharlineedit.cpp b/kregexpeditor/limitedcharlineedit.cpp
index 59a6309..5e494d8 100644
--- a/kregexpeditor/limitedcharlineedit.cpp
+++ b/kregexpeditor/limitedcharlineedit.cpp
@@ -67,7 +67,7 @@ LimitedCharLineEdit::LimitedCharLineEdit( Mode mode, TQWidget* parent, const cha
_count = 4;
setMaxLength( _count );
- setFixedSize( fontMetrics().width('A')*5+5, tqsizeHint().height());
+ setFixedSize( fontMetrics().width('A')*5+5, sizeHint().height());
setValidator( new Validator( mode, this ) );
}
diff --git a/kregexpeditor/lookaheadwidget.h b/kregexpeditor/lookaheadwidget.h
index 302090a..36c4e42 100644
--- a/kregexpeditor/lookaheadwidget.h
+++ b/kregexpeditor/lookaheadwidget.h
@@ -32,7 +32,7 @@ public:
virtual RegExp* regExp() const;
virtual RegExpType type() const { return _tp; }
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExpWidget* findWidgetToEdit( TQPoint globalPos );
diff --git a/kregexpeditor/main.cpp b/kregexpeditor/main.cpp
index 58c569d..47c323c 100644
--- a/kregexpeditor/main.cpp
+++ b/kregexpeditor/main.cpp
@@ -47,7 +47,7 @@ int main( int argc, char* argv[] )
TQVBoxLayout* lay = new TQVBoxLayout( top, 6 );
KRegExpEditorGUI* iface = new KRegExpEditorGUI( top, "_editor", TQStringList() );
- iface->doSomething( TQString::tqfromLatin1("setAllowNonTQtSyntax"), (bool*) true );
+ iface->doSomething( TQString::fromLatin1("setAllowNonTQtSyntax"), (bool*) true );
lay->addWidget( iface );
TQHBoxLayout* lay2 = new TQHBoxLayout( lay, 6 );
diff --git a/kregexpeditor/multicontainerwidget.cpp b/kregexpeditor/multicontainerwidget.cpp
index d8bef97..7f72e04 100644
--- a/kregexpeditor/multicontainerwidget.cpp
+++ b/kregexpeditor/multicontainerwidget.cpp
@@ -261,5 +261,5 @@ void MultiContainerWidget::updateCursorRecursively()
for ( TQPtrListIterator<RegExpWidget> it(_tqchildren); *it ; ++it ) {
(*it)->updateCursorRecursively();
}
- updatetqCursorShape();
+ updateCursorShape();
}
diff --git a/kregexpeditor/myfontmetrics.cpp b/kregexpeditor/myfontmetrics.cpp
index 38eb7dd..05b4ef3 100644
--- a/kregexpeditor/myfontmetrics.cpp
+++ b/kregexpeditor/myfontmetrics.cpp
@@ -19,7 +19,7 @@
TQSize HackCalculateFontSize(TQFontMetrics fm, TQString str )
{
- TQStringList list = TQStringList::split( TQString::tqfromLatin1("\n"), str );
+ TQStringList list = TQStringList::split( TQString::fromLatin1("\n"), str );
int maxWidth = 0;
int height = 0;
for ( TQStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
diff --git a/kregexpeditor/qregexpparser.y b/kregexpeditor/qregexpparser.y
index 6e9dc5e..75eeaa2 100644
--- a/kregexpeditor/qregexpparser.y
+++ b/kregexpeditor/qregexpparser.y
@@ -102,11 +102,11 @@ expression : expression TOK_Bar term {
$<regexp>$ = new AltnRegExp( false );
dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( $<regexp>1 );
}
- dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( new TextRegExp( false, QString::tqfromLatin1("") ) );
+ dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( new TextRegExp( false, QString::fromLatin1("") ) );
}
| TOK_Bar term {
$<regexp>$ = new AltnRegExp( false );
- dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( new TextRegExp( false, QString::tqfromLatin1("") ) );
+ dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( new TextRegExp( false, QString::fromLatin1("") ) );
dynamic_cast<AltnRegExp*>( $<regexp>$ )->addRegExp( $<regexp>2 );
}
| TOK_Bar { $<regexp>$ = new AltnRegExp( false ); }
diff --git a/kregexpeditor/qtregexpconverter.cpp b/kregexpeditor/qtregexpconverter.cpp
index 72f9290..ab37244 100644
--- a/kregexpeditor/qtregexpconverter.cpp
+++ b/kregexpeditor/qtregexpconverter.cpp
@@ -51,11 +51,11 @@ TQString TQtRegExpConverter::toString( AltnRegExp* regexp, bool markSelection )
RegExpList list = regexp->tqchildren();
for ( RegExpListIt it(list); *it; ++it ) {
if ( !first ) {
- res += TQString::tqfromLatin1( "|" );
+ res += TQString::fromLatin1( "|" );
}
first = false;
if ( markSelection && !regexp->isSelected() && (*it)->isSelected() ) {
- res += TQString::tqfromLatin1("(") + toStr( *it, markSelection ) + TQString::tqfromLatin1(")");
+ res += TQString::fromLatin1("(") + toStr( *it, markSelection ) + TQString::fromLatin1(")");
}
else {
res += toStr( *it, markSelection );
@@ -77,25 +77,25 @@ TQString TQtRegExpConverter::toString( ConcRegExp* regexp, bool markSelection )
if ( markSelection )
startPar = TQString::fromLocal8Bit("(?:");
else
- startPar = TQString::tqfromLatin1( "(" );
- endPar = TQString::tqfromLatin1( ")" );
+ startPar = TQString::fromLatin1( "(" );
+ endPar = TQString::fromLatin1( ")" );
}
// Note these two have different tests! They are activated in each their iteration of the loop.
if ( markSelection && !childSelected && !regexp->isSelected() && (*it)->isSelected() ) {
- res += TQString::tqfromLatin1("(");
+ res += TQString::fromLatin1("(");
childSelected = true;
}
if ( markSelection && childSelected && !regexp->isSelected() && !(*it)->isSelected() ) {
- res += TQString::tqfromLatin1(")");
+ res += TQString::fromLatin1(")");
childSelected= false;
}
res += startPar + toStr( *it, markSelection ) + endPar;
}
if ( markSelection && childSelected && !regexp->isSelected() ) {
- res += TQString::tqfromLatin1(")");
+ res += TQString::fromLatin1(")");
}
return res;
}
@@ -103,9 +103,9 @@ TQString TQtRegExpConverter::toString( ConcRegExp* regexp, bool markSelection )
TQString TQtRegExpConverter::toString( LookAheadRegExp* regexp, bool markSelection )
{
if ( regexp->lookAheadType() == LookAheadRegExp::POSITIVE )
- return TQString::tqfromLatin1( "(?=" ) + toStr( regexp->child(), markSelection ) + TQString::fromLocal8Bit( ")" );
+ return TQString::fromLatin1( "(?=" ) + toStr( regexp->child(), markSelection ) + TQString::fromLocal8Bit( ")" );
else
- return TQString::tqfromLatin1( "(?!" ) + toStr( regexp->child(), markSelection ) + TQString::fromLocal8Bit( ")" );
+ return TQString::fromLatin1( "(?!" ) + toStr( regexp->child(), markSelection ) + TQString::fromLocal8Bit( ")" );
}
TQString TQtRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSelection*/ )
@@ -137,7 +137,7 @@ TQString TQtRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSelec
// Now insert the ranges.
TQPtrList<StringPair> ranges = regexp->range();
for ( TQPtrListIterator<StringPair> it(ranges); *it; ++it ) {
- txt.append((*it)->first()+ TQString::tqfromLatin1("-")+ (*it)->second());
+ txt.append((*it)->first()+ TQString::fromLatin1("-")+ (*it)->second());
}
// Ok, its time to build each part of the regexp, here comes the rule:
@@ -147,20 +147,20 @@ TQString TQtRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSelec
// finally if '^' is one of the characters, then it must not be the first
// one!
- TQString res = TQString::tqfromLatin1("[");
+ TQString res = TQString::fromLatin1("[");
if ( regexp->negate() )
- res.append(TQString::tqfromLatin1("^"));
+ res.append(TQString::fromLatin1("^"));
// a ']' must be the first character in teh range.
if ( foundParenthesis ) {
- res.append(TQString::tqfromLatin1("]"));
+ res.append(TQString::fromLatin1("]"));
}
// a '-' must be the first character ( only coming after a ']')
if ( foundDash ) {
- res.append(TQString::tqfromLatin1("-"));
+ res.append(TQString::fromLatin1("-"));
}
res += txt;
@@ -184,7 +184,7 @@ TQString TQtRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSelec
res.append( TQChar( '^' ) );
}
- res.append(TQString::tqfromLatin1("]"));
+ res.append(TQString::fromLatin1("]"));
return res;
}
@@ -192,30 +192,30 @@ TQString TQtRegExpConverter::toString( TextRangeRegExp* regexp, bool /*markSelec
TQString TQtRegExpConverter::toString( CompoundRegExp* regexp, bool markSelection )
{
if ( markSelection && !regexp->isSelected() && regexp->child()->isSelected() )
- return TQString::tqfromLatin1( "(" ) + toStr( regexp->child(), markSelection ) + TQString::tqfromLatin1( ")" );
+ return TQString::fromLatin1( "(" ) + toStr( regexp->child(), markSelection ) + TQString::fromLatin1( ")" );
else
return toStr( regexp->child(), markSelection );
}
TQString TQtRegExpConverter::toString( DotRegExp* /*regexp*/, bool /*markSelection*/ )
{
- return TQString::tqfromLatin1( "." );
+ return TQString::fromLatin1( "." );
}
TQString TQtRegExpConverter::toString( PositionRegExp* regexp, bool /*markSelection*/ )
{
switch (regexp->position()) {
case PositionRegExp::BEGLINE:
- return TQString::tqfromLatin1("^");
+ return TQString::fromLatin1("^");
case PositionRegExp::ENDLINE:
- return TQString::tqfromLatin1("$");
+ return TQString::fromLatin1("$");
case PositionRegExp::WORDBOUNDARY:
- return TQString::tqfromLatin1("\\b");
+ return TQString::fromLatin1("\\b");
case PositionRegExp::NONWORDBOUNDARY:
- return TQString::tqfromLatin1("\\B");
+ return TQString::fromLatin1("\\B");
}
Q_ASSERT( false );
- return TQString::tqfromLatin1("");
+ return TQString::fromLatin1("");
}
TQString TQtRegExpConverter::toString( RepeatRegExp* regexp, bool markSelection )
@@ -227,17 +227,17 @@ TQString TQtRegExpConverter::toString( RepeatRegExp* regexp, bool markSelection
if ( markSelection ) {
if ( !regexp->isSelected() && child->isSelected()) {
- startPar = TQString::tqfromLatin1( "(" );
- endPar = TQString::tqfromLatin1( ")" );
+ startPar = TQString::fromLatin1( "(" );
+ endPar = TQString::fromLatin1( ")" );
}
else if ( child->precedence() < regexp->precedence() ) {
- startPar = TQString::tqfromLatin1( "(?:" );
- endPar = TQString::tqfromLatin1( ")" );
+ startPar = TQString::fromLatin1( "(?:" );
+ endPar = TQString::fromLatin1( ")" );
}
}
else if ( child->precedence() < regexp->precedence() ) {
- startPar = TQString::tqfromLatin1( "(" );
- endPar = TQString::tqfromLatin1( ")" );
+ startPar = TQString::fromLatin1( "(" );
+ endPar = TQString::fromLatin1( ")" );
}
if ( regexp->min() == 0 && regexp->max() == -1) {
@@ -285,7 +285,7 @@ TQString TQtRegExpConverter::toString( TextRegExp* regexp, bool /*markSelection*
TQString TQtRegExpConverter::name()
{
- return TQString::tqfromLatin1( "TQt" );
+ return TQString::fromLatin1( "TQt" );
}
int TQtRegExpConverter::features()
diff --git a/kregexpeditor/regexp.cpp b/kregexpeditor/regexp.cpp
index cb94e84..11a8788 100644
--- a/kregexpeditor/regexp.cpp
+++ b/kregexpeditor/regexp.cpp
@@ -68,7 +68,7 @@ RegExp* RegExp::readRegExp( TQDomElement top, const TQString& version )
TQString RegExp::toXmlString() const
{
TQDomDocument doc;
- doc.setContent( TQString::tqfromLatin1( "<RegularExpression/>" ) );
+ doc.setContent( TQString::fromLatin1( "<RegularExpression/>" ) );
TQDomNode top = doc.documentElement();
top.toElement().setAttribute(TQString::fromLocal8Bit("version"), KRegExpEditorGUI::version);
diff --git a/kregexpeditor/regexpbuttons.cpp b/kregexpeditor/regexpbuttons.cpp
index abbfb38..0456816 100644
--- a/kregexpeditor/regexpbuttons.cpp
+++ b/kregexpeditor/regexpbuttons.cpp
@@ -53,7 +53,7 @@ RegExpButtons::RegExpButtons( TQWidget *parent, const char *name )
TQPixmap pix;
pix.convertFromImage( qembed_findImage( "select" ) );
#else
- TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::tqfromLatin1("kregexpeditor/pics/select.png") ), KIcon::Toolbar );
+ TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::fromLatin1("kregexpeditor/pics/select.png") ), KIcon::Toolbar );
#endif
_selectBut->setPixmap( pix );
@@ -156,10 +156,10 @@ DoubleClickButton* RegExpButtons::insert(RegExpType tp, const char* name, TQStri
{
#ifdef TQT_ONLY
TQPixmap pix;
- pix.convertFromImage( qembed_findImage( TQString::tqfromLatin1( name ) ) );
+ pix.convertFromImage( qembed_findImage( TQString::fromLatin1( name ) ) );
#else
- TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::tqfromLatin1("kregexpeditor/pics/")+TQString::tqfromLatin1(name) +
- TQString::tqfromLatin1(".png") ), KIcon::Toolbar );
+ TQPixmap pix = KGlobal::iconLoader()->loadIcon(locate("data", TQString::fromLatin1("kregexpeditor/pics/")+TQString::fromLatin1(name) +
+ TQString::fromLatin1(".png") ), KIcon::Toolbar );
#endif
DoubleClickButton* but = new DoubleClickButton( pix, this, "RegExpButtons::but");
diff --git a/kregexpeditor/regexpconverter.cpp b/kregexpeditor/regexpconverter.cpp
index 951f0d7..2678591 100644
--- a/kregexpeditor/regexpconverter.cpp
+++ b/kregexpeditor/regexpconverter.cpp
@@ -53,7 +53,7 @@ TQString RegExpConverter::toStr( RegExp* regexp, bool markSelection )
case RegExp::TEXTRANGE: return toString( static_cast<TextRangeRegExp*>( regexp ), markSelection );
}
qWarning("We shouldn't get here!");
- return TQString::tqfromLatin1( "" );
+ return TQString::fromLatin1( "" );
}
diff --git a/kregexpeditor/regexpwidget.cpp b/kregexpeditor/regexpwidget.cpp
index c164c51..d6179b4 100644
--- a/kregexpeditor/regexpwidget.cpp
+++ b/kregexpeditor/regexpwidget.cpp
@@ -164,10 +164,10 @@ TQRect RegExpWidget::selectionRect() const
void RegExpWidget::enterEvent( TQEvent * )
{
- updatetqCursorShape();
+ updateCursorShape();
}
-void RegExpWidget::updatetqCursorShape()
+void RegExpWidget::updateCursorShape()
{
TQCursor cursor;
@@ -191,7 +191,7 @@ void RegExpWidget::updatetqCursorShape()
void RegExpWidget::updateCursorRecursively()
{
- updatetqCursorShape();
+ updateCursorShape();
}
diff --git a/kregexpeditor/regexpwidget.h b/kregexpeditor/regexpwidget.h
index 2fd455a..699f13f 100644
--- a/kregexpeditor/regexpwidget.h
+++ b/kregexpeditor/regexpwidget.h
@@ -148,7 +148,7 @@ public:
@li accept cursor for insert/paste
@li reject cursor for insert/paste
*/
- void updatetqCursorShape();
+ void updateCursorShape();
virtual void updateCursorRecursively();
diff --git a/kregexpeditor/repeatregexp.cpp b/kregexpeditor/repeatregexp.cpp
index 3a03e90..6b855f2 100644
--- a/kregexpeditor/repeatregexp.cpp
+++ b/kregexpeditor/repeatregexp.cpp
@@ -58,7 +58,7 @@ bool RepeatRegExp::load( TQDomElement top, const TQString& version )
if ( !ok ) {
KMessageBox::sorry( 0, i18n("<p>Value for attribute <b>%1</b> was not an integer for element "
"<b>%2</b></p><p>It contained the value <b>%3</b></p>")
- .tqarg(TQString::tqfromLatin1("lower")).tqarg(TQString::tqfromLatin1("Repeat")).tqarg(lower),
+ .tqarg(TQString::fromLatin1("lower")).tqarg(TQString::fromLatin1("Repeat")).tqarg(lower),
i18n("Error While Loading From XML File") ) ;
_lower = 0;
}
@@ -66,7 +66,7 @@ bool RepeatRegExp::load( TQDomElement top, const TQString& version )
if ( !ok ) {
KMessageBox::sorry( 0, i18n("<p>Value for attribute <b>%1</b> was not an integer for element "
"<b>%2</b></p><p>It contained the value <b>%3</b></p>")
- .tqarg(TQString::tqfromLatin1("upper")).tqarg(TQString::tqfromLatin1("Repeat")).tqarg(upper),
+ .tqarg(TQString::fromLatin1("upper")).tqarg(TQString::fromLatin1("Repeat")).tqarg(upper),
i18n("Error While Loading From XML File") ) ;
_upper = -1;
}
diff --git a/kregexpeditor/repeatwidget.h b/kregexpeditor/repeatwidget.h
index 8911461..98ea6ee 100644
--- a/kregexpeditor/repeatwidget.h
+++ b/kregexpeditor/repeatwidget.h
@@ -80,7 +80,7 @@ public:
RepeatWidget( RepeatRegExp* regexp, RegExpEditorWindow* editorWindow,
TQWidget* parent, const char* name = 0);
void init();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return REPEAT; }
virtual int edit();
diff --git a/kregexpeditor/scrollededitorwindow.cpp b/kregexpeditor/scrollededitorwindow.cpp
index b14261c..07e8bf0 100644
--- a/kregexpeditor/scrollededitorwindow.cpp
+++ b/kregexpeditor/scrollededitorwindow.cpp
@@ -106,7 +106,7 @@ void RegExpScrolledEditorWindow::resizeEvent( TQResizeEvent *event )
void RegExpScrolledEditorWindow::slotUpdateContentSize( TQPoint focusPoint )
{
- TQSize childSize = _editorWindow->tqsizeHint();
+ TQSize childSize = _editorWindow->sizeHint();
TQSize vpSize = _scrollView->viewportSize(10,10);
bool change = false;
diff --git a/kregexpeditor/selectablelineedit.cpp b/kregexpeditor/selectablelineedit.cpp
index ac42c83..25f0a00 100644
--- a/kregexpeditor/selectablelineedit.cpp
+++ b/kregexpeditor/selectablelineedit.cpp
@@ -43,13 +43,13 @@ void SelectableLineEdit::setSelected( bool selected )
tqrepaint();
}
-TQSize SelectableLineEdit::tqsizeHint() const
+TQSize SelectableLineEdit::sizeHint() const
{
int frameWidth = frame() ? 8 : 4; // from TQLineEdit source
TQFontMetrics metrics = fontMetrics();
int actualSize = metrics.width( text() );
int charWidth = metrics.maxWidth();
- int height = TQLineEdit::tqsizeHint().height();
+ int height = TQLineEdit::sizeHint().height();
int width;
if ( hasFocus() )
diff --git a/kregexpeditor/selectablelineedit.h b/kregexpeditor/selectablelineedit.h
index 7fb7ad7..79522b3 100644
--- a/kregexpeditor/selectablelineedit.h
+++ b/kregexpeditor/selectablelineedit.h
@@ -39,7 +39,7 @@ Q_OBJECT
public:
SelectableLineEdit( RegExpWidget* owner, TQWidget* parent = 0, const char* name = 0);
void setSelected( bool selected );
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
protected slots:
void slotKeyPressed();
diff --git a/kregexpeditor/singlecontainerwidget.cpp b/kregexpeditor/singlecontainerwidget.cpp
index 2413236..27035af 100644
--- a/kregexpeditor/singlecontainerwidget.cpp
+++ b/kregexpeditor/singlecontainerwidget.cpp
@@ -126,7 +126,7 @@ void SingleContainerWidget::updateAll()
void SingleContainerWidget::updateCursorRecursively()
{
_child->updateCursorRecursively();
- updatetqCursorShape();
+ updateCursorShape();
}
diff --git a/kregexpeditor/test-without-dl/main.cpp b/kregexpeditor/test-without-dl/main.cpp
index 76e2fbe..0094b4a 100644
--- a/kregexpeditor/test-without-dl/main.cpp
+++ b/kregexpeditor/test-without-dl/main.cpp
@@ -50,9 +50,9 @@ int main( int argc, char* argv[] )
tqApp->installEventFilter( new ShootABug() );
KRegExpEditorGUIDialog* iface = new KRegExpEditorGUIDialog( 0, "_editor", TQStringList() );
- iface->setRegExp( TQString::tqfromLatin1( "#include" ) );
+ iface->setRegExp( TQString::fromLatin1( "#include" ) );
iface->doSomething( "setMinimal", (void*) false );
- iface->doSomething( "setSyntax", (void*) new TQString( TQString::tqfromLatin1( "Emacs" ) ) );
+ iface->doSomething( "setSyntax", (void*) new TQString( TQString::fromLatin1( "Emacs" ) ) );
iface->doSomething( "setShowSyntaxCombo", (bool*) true );
TQFile file("/packages/kde-src/tdeutils/kregexpeditor/test/main.cpp");
diff --git a/kregexpeditor/textregexp.cpp b/kregexpeditor/textregexp.cpp
index d53d916..c31f9ac 100644
--- a/kregexpeditor/textregexp.cpp
+++ b/kregexpeditor/textregexp.cpp
@@ -62,7 +62,7 @@ bool TextRegExp::load( TQDomElement top, const TQString& /*version*/)
_text = txtNode.data();
}
else {
- _text = TQString::tqfromLatin1( "" );
+ _text = TQString::fromLatin1( "" );
}
return true;
diff --git a/kregexpeditor/textwidget.cpp b/kregexpeditor/textwidget.cpp
index 99a77e1..9c58e66 100644
--- a/kregexpeditor/textwidget.cpp
+++ b/kregexpeditor/textwidget.cpp
@@ -66,9 +66,9 @@ void TextWidget::slotUpdate()
_editorWindow->updateContent( this );
}
-TQSize TextWidget::tqsizeHint() const
+TQSize TextWidget::sizeHint() const
{
- return _edit->tqsizeHint();
+ return _edit->sizeHint();
}
void TextWidget::paintEvent( TQPaintEvent *e)
diff --git a/kregexpeditor/textwidget.h b/kregexpeditor/textwidget.h
index 71ccf9b..ac1c069 100644
--- a/kregexpeditor/textwidget.h
+++ b/kregexpeditor/textwidget.h
@@ -37,7 +37,7 @@ public:
const char *name = 0);
TextWidget( TextRegExp* regexp, RegExpEditorWindow* editorWindow,
TQWidget* parent, const char* name = 0);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return TEXT; }
virtual void updateAll();
diff --git a/kregexpeditor/userdefinedregexps.cpp b/kregexpeditor/userdefinedregexps.cpp
index 85dc96e..385ea69 100644
--- a/kregexpeditor/userdefinedregexps.cpp
+++ b/kregexpeditor/userdefinedregexps.cpp
@@ -68,7 +68,7 @@ void UserDefinedRegExps::slotPopulateUserRegexps()
#ifdef TQT_ONLY
TQStringList dirs;
- dirs << TQString::tqfromLatin1( "predefined" );
+ dirs << TQString::fromLatin1( "predefined" );
#else
TQStringList dirs = KGlobal::dirs()->findDirs( "data", TQString::fromLocal8Bit("kregexpeditor/predefined/") );
#endif
@@ -88,7 +88,7 @@ void UserDefinedRegExps::slotPopulateUserRegexps()
void UserDefinedRegExps::createItems( const TQString& _title, const TQString& dir, bool usersRegExp )
{
TQString title = _title;
- if (_title == TQString::tqfromLatin1("general"))
+ if (_title == TQString::fromLatin1("general"))
title = i18n("General");
TQListViewItem* lvItem = new TQListViewItem( _userDefined, title );
@@ -256,7 +256,7 @@ void WidgetWinItem::setName( const TQString& nm )
TQString WidgetWinItem::path()
{
#ifdef TQT_ONLY
- return TQString::tqfromLatin1( "predefined" );
+ return TQString::fromLatin1( "predefined" );
#else
return locateLocal("data", TQString::fromLocal8Bit("KRegExpEditor/"));
#endif
diff --git a/kregexpeditor/util.cpp b/kregexpeditor/util.cpp
index b6cf4c6..a57f99c 100644
--- a/kregexpeditor/util.cpp
+++ b/kregexpeditor/util.cpp
@@ -26,7 +26,7 @@ TQPixmap Util::getKRegExpEditorIcon( const TQString& name )
pix.convertFromImage( qembed_findImage(name) );
return pix;
#else
- return KGlobal::iconLoader()->loadIcon(locate("data", TQString::tqfromLatin1("kregexpeditor/pics/") +name ),
+ return KGlobal::iconLoader()->loadIcon(locate("data", TQString::fromLatin1("kregexpeditor/pics/") +name ),
KIcon::Toolbar );
#endif
}
diff --git a/kregexpeditor/verifier.cpp b/kregexpeditor/verifier.cpp
index 18e1be3..2b6649b 100644
--- a/kregexpeditor/verifier.cpp
+++ b/kregexpeditor/verifier.cpp
@@ -97,7 +97,7 @@ void Verifier::setMinimal( bool b )
//
// void Verifier::gotoNum( int which )
// {
-// TQString anchor = TQString::tqfromLatin1("match%1").tqarg(which);
+// TQString anchor = TQString::fromLatin1("match%1").tqarg(which);
// scrollToAnchor( anchor );
// _current = which;
// emit currentChanged( _current );
diff --git a/kregexpeditor/verifybuttons.cpp b/kregexpeditor/verifybuttons.cpp
index 675d3e6..e36e934 100644
--- a/kregexpeditor/verifybuttons.cpp
+++ b/kregexpeditor/verifybuttons.cpp
@@ -45,7 +45,7 @@ VerifyButtons::VerifyButtons( TQWidget* parent, const char* name )
TQBoxLayout* tqlayout = boxLayout();
_verify = new TQToolButton(this);
- TQIconSet icon = Util::getSystemIconSet( TQString::tqfromLatin1("spellcheck"));
+ TQIconSet icon = Util::getSystemIconSet( TQString::fromLatin1("spellcheck"));
_verify->setIconSet( icon );
TQToolTip::add( _verify, i18n( "Verify regular expression" ) );
TQWhatsThis::add( _verify, i18n("Shows what part of the regular expression is being matched in the <i>verifier window</i>."
@@ -54,35 +54,35 @@ VerifyButtons::VerifyButtons( TQWidget* parent, const char* name )
connect( _verify, TQT_SIGNAL( clicked() ), this, TQT_SIGNAL( verify() ) );
TQToolButton* button = new TQToolButton(this);
- button->setPixmap( Util::getSystemIcon( TQString::tqfromLatin1("fileopen")) );
+ button->setPixmap( Util::getSystemIcon( TQString::fromLatin1("fileopen")) );
tqlayout->addWidget( button );
connect(button, TQT_SIGNAL(clicked()), this, TQT_SLOT(loadText()));
TQToolTip::add( button, i18n("Load text in the verifier window") );
button = new TQToolButton(this);
- button->setPixmap( Util::getSystemIcon( TQString::tqfromLatin1("package_settings")) );
+ button->setPixmap( Util::getSystemIcon( TQString::fromLatin1("package_settings")) );
tqlayout->addWidget( button );
connect(button, TQT_SIGNAL(clicked()), this, TQT_SLOT(configure()));
TQToolTip::add( button, i18n("Settings") );
// It is currently not possible to ask for the paragraph being highlighted, thefore scrolling to next/prev match
// do not work. Enable this when they work.
- // _first = new TQToolButton( TQString::tqfromLatin1("<<"), this);
+ // _first = new TQToolButton( TQString::fromLatin1("<<"), this);
// tqlayout->addWidget( _first );
// connect(_first, TQT_SIGNAL(clicked()), this, TQT_SIGNAL( gotoFirst()));
// _first->setFixedWidth( 25 );
//
- // _prev = new TQToolButton(TQString::tqfromLatin1("<"), this);
+ // _prev = new TQToolButton(TQString::fromLatin1("<"), this);
// tqlayout->addWidget( _prev );
// connect(_prev, TQT_SIGNAL(clicked()), this, TQT_SIGNAL( gotoPrev()));
// _prev->setFixedWidth( 20 );
//
- // _next = new TQToolButton(TQString::tqfromLatin1(">"), this);
+ // _next = new TQToolButton(TQString::fromLatin1(">"), this);
// tqlayout->addWidget( _next );
// connect(_next, TQT_SIGNAL(clicked()), this, TQT_SIGNAL( gotoNext()));
// _next->setFixedWidth( 20 );
//
- // _last = new TQToolButton(TQString::tqfromLatin1(">>"), this);
+ // _last = new TQToolButton(TQString::fromLatin1(">>"), this);
// tqlayout->addWidget( _last );
// connect(_last, TQT_SIGNAL(clicked()), this, TQT_SIGNAL( gotoLast()));
// _last->setFixedWidth( 25 );
@@ -179,7 +179,7 @@ void VerifyButtons::setMatchCount( int /*count*/ )
// currently this is not possible due to limitation in TQSyntaxHighlighter
/*
if ( count == -1 )
- _matches->setText( TQString::tqfromLatin1("-") );
+ _matches->setText( TQString::fromLatin1("-") );
else
_matches->setText( TQString::number( count ) );
*/
diff --git a/kregexpeditor/widgetfactory.cpp b/kregexpeditor/widgetfactory.cpp
index 9f167b2..a5866d6 100644
--- a/kregexpeditor/widgetfactory.cpp
+++ b/kregexpeditor/widgetfactory.cpp
@@ -191,14 +191,14 @@ RegExp* WidgetFactory::createRegExp( TQString str )
// Read the RegularExpression element, and extract the version.
TQDomElement top = doc.documentElement();
if (! (top.tagName() == TQString::fromLocal8Bit("RegularExpression")) ) {
- KMessageBox::sorry( 0, i18n("<p>XML file did not contain a <b>%1</b> tag.</p>").tqarg(TQString::tqfromLatin1("RegularExpression")),
+ KMessageBox::sorry( 0, i18n("<p>XML file did not contain a <b>%1</b> tag.</p>").tqarg(TQString::fromLatin1("RegularExpression")),
i18n("Error While Loading From XML File") ) ;
}
TQString version = top.attribute( TQString::fromLocal8Bit("version"), KRegExpEditorGUI::version );
TQDomNode child = top.firstChild();
if ( ! child.isElement() ) {
KMessageBox::sorry( 0, i18n("<p>Error while reading XML file. The element just below the tag "
- "<b>%1</b> was not an element.</p>").tqarg(TQString::tqfromLatin1("RegularExpression")),
+ "<b>%1</b> was not an element.</p>").tqarg(TQString::fromLatin1("RegularExpression")),
i18n("Error While Loading From XML File") ) ;
}
diff --git a/kregexpeditor/zerowidgets.cpp b/kregexpeditor/zerowidgets.cpp
index eaf1aaf..7d98609 100644
--- a/kregexpeditor/zerowidgets.cpp
+++ b/kregexpeditor/zerowidgets.cpp
@@ -42,7 +42,7 @@ void ZeroWidget::addNewChild(DragAccepter *, RegExpWidget *)
qFatal("No tqchildren should be added to this widget!");
}
-TQSize ZeroWidget::tqsizeHint() const
+TQSize ZeroWidget::sizeHint() const
{
TQFontMetrics metrics = fontMetrics();
_textSize = HackCalculateFontSize( metrics, _text );
@@ -54,7 +54,7 @@ TQSize ZeroWidget::tqsizeHint() const
void ZeroWidget::paintEvent( TQPaintEvent *e)
{
// So what is my Size?
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize);
diff --git a/kregexpeditor/zerowidgets.h b/kregexpeditor/zerowidgets.h
index 780f426..04dd5c7 100644
--- a/kregexpeditor/zerowidgets.h
+++ b/kregexpeditor/zerowidgets.h
@@ -30,7 +30,7 @@ public:
ZeroWidget(TQString text, RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual void addNewChild(DragAccepter *accepter, RegExpWidget *child);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
protected:
virtual void paintEvent( TQPaintEvent *e );
diff --git a/kregexpeditor/lookaheadwidget.cpp b/kregexpeditor/lookaheadwidget.cpp
index c5dc700..5ae0b9d 100644
--- a/kregexpeditor/lookaheadwidget.cpp
+++ b/kregexpeditor/lookaheadwidget.cpp
@@ -60,13 +60,13 @@ RegExp* LookAheadWidget::regExp() const
_child->regExp() );
}
-TQSize LookAheadWidget::tqsizeHint() const
+TQSize LookAheadWidget::sizeHint() const
{
// TODO: Merge with RepeatWidget::tqsizeHint
TQFontMetrics metrics = fontMetrics();
_textSize = metrics.size( 0, _text );
- _childSize = _child->tqsizeHint();
+ _childSize = _child->sizeHint();
int height = _textSize.height() + bdSize + _childSize.height() + bdSize + 2*pw;
int width = 2 * pw + TQMAX(_childSize.width(), 4*bdSize + _textSize.width());
@@ -76,7 +76,7 @@ TQSize LookAheadWidget::tqsizeHint() const
void LookAheadWidget::paintEvent( TQPaintEvent *e )
{
// TODO: Merge with RepeatWidget::paintEvent
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize );
@@ -60,13 +60,13 @@ RegExp* LookAheadWidget::regExp() const
{
- // TODO: Merge with RepeatWidget::tqsizeHint
+ // TODO: Merge with RepeatWidget::sizeHint
TQFontMetrics metrics = fontMetrics();
_textSize = metrics.size( 0, _text );
diff --git a/kregexpeditor/repeatwidget.cpp b/kregexpeditor/repeatwidget.cpp
index 86f87f9..0d086c7 100644
--- a/kregexpeditor/repeatwidget.cpp
+++ b/kregexpeditor/repeatwidget.cpp
@@ -85,13 +85,13 @@ void RepeatWidget::init()
}
-TQSize RepeatWidget::tqsizeHint() const
+TQSize RepeatWidget::sizeHint() const
{
// TODO: Merge with LookAheadWidget::tqsizeHint
TQFontMetrics metrics = fontMetrics();
_textSize = metrics.size( 0, _content->text() );
- _childSize = _child->tqsizeHint();
+ _childSize = _child->sizeHint();
int height = _textSize.height() + bdSize + _childSize.height() + bdSize + 2*pw;
int width = 2 * pw + TQMAX(_childSize.width(), 4*bdSize + _textSize.width());
@@ -101,7 +101,7 @@ TQSize RepeatWidget::tqsizeHint() const
void RepeatWidget::paintEvent( TQPaintEvent *e )
{
// TODO: Merge with LookAheadWidget::paintEvent
- TQSize mySize = tqsizeHint();
+ TQSize mySize = sizeHint();
TQPainter painter(this);
drawPossibleSelection( painter, mySize );
@@ -157,8 +157,8 @@ void RepeatWidget::slotConfigCanceled()
int RepeatWidget::edit()
{
- _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->tqsizeHint().width()/2,
- _configWindow->tqsizeHint().height()/2) );
+ _configWindow->move(TQCursor::pos() - TQPoint(_configWindow->sizeHint().width()/2,
+ _configWindow->sizeHint().height()/2) );
TQDataStream stream( _backup, IO_WriteOnly );
KWidgetStreamer streamer;
streamer.toStream( TQT_TQOBJECT(_content), stream );
@@ -85,13 +85,13 @@ void RepeatWidget::init()
{
- // TODO: Merge with LookAheadWidget::tqsizeHint
+ // TODO: Merge with LookAheadWidget::sizeHint
TQFontMetrics metrics = fontMetrics();
_textSize = metrics.size( 0, _content->text() );